#!/bin/sh
#
VERSION=1.2

ARG1="$1"

if [ -e ${ARG1} ];then
    ADDITIONALDATA="${ARG1}"
fi


TMPDATA=$(mktemp -d  -t benno-support-info_XXXXXXXXXXX)
TARDATA="${TMPDATA}/benno-config.tar"
CERTFILE="${TMPDATA}/cert.pem"
ENCFILE="${TMPDATA}/benno-config.data"
NOW=$(date +%y%m%d%H%M%S)
sleep 1
TAROUT="/tmp/benno-config_${NOW}.tar.gz"
ENCOUT="/tmp/benno-config_${NOW}.data"

(
echo "** Networking"
echo "* IP adresses"
/sbin/ip address show
echo ""
echo "* Hostname"
cat /etc/hostname
echo ""
echo "* Hosts file"
cat /etc/hosts
echo ""
echo "* TCP ports listening"
netstat -ltnp
echo ""
echo "** Filesystem"
echo "* /etc/benno"
ls -la /etc/benno
echo ""
echo "* /etc/benno-web"
ls -la /etc/benno-web
ls -la /etc/benno-web/auth.d
echo ""
echo "* /var/lib/benno-web"
ls -la /var/lib/benno-web
echo ""
echo "* /srv/benno"
ls -la /srv/benno
ls -la /srv/benno/archive
echo ""
echo "* DB VERSION"
[ -f /usr/bin/sqlite3 ] && sqlite3 /var/lib/benno-web/bennoweb.sqlite "SELECT id,value FROM appstate WHERE id = 'dbversion';"
) > ${TMPDATA}/systemconfig.txt
perl -p \
    -e 's/(authKey.*?\>)\w+?\</$1*************************/g;' \
    -e 's/(endpoint\>).+?\</$1*************************/g;' \
    -e 's/(region\>).+?\</$1*************************/g;' \
    -e 's/(privateKey.*?\>)\w+?\</$1*************************/g;' \
    -e 's/(keyPassword.*?\>)\w+?\</$1*************************/g;' \
    /etc/benno/benno.xml  > ${TMPDATA}/benno.xml
cd ${TMPDATA}
tar -chf \
    ${TARDATA} \
    ./benno.xml \
    /etc/benno/jetty.xml \
    /etc/benno/benno.lic \
    /etc/benno-web/benno.conf \
    /srv/benno/system \
    systemconfig.txt $ADDITIONALDATA 2>/dev/null
tar --newer="-7 days" -rhf ${TARDATA} /var/log/benno/ /var/log/apache2/
gzip ${TARDATA}
TARGZ="${TARDATA}.gz"

echo "
-----BEGIN CERTIFICATE-----
MIIENDCCAxygAwIBAgIJAJZpgxKEZP8mMA0GCSqGSIb3DQEBCwUAMIGuMQswCQYD
VQQGEwJERTEWMBQGA1UECAwNTmllZGVyc2FjaHNlbjESMBAGA1UEBwwJQmFkIEli
dXJnMSAwHgYDVQQKDBdMV3N5c3RlbXMgR21iSCAmIENvLiBLRzElMCMGA1UEAwwc
QmVubm8gTWFpbEFyY2hpdiBTdXBwb3J0aW5mbzEqMCgGCSqGSIb3DQEJARYbc3Vw
cG9ydEBiZW5uby1tYWlsYXJjaGl2LmRlMB4XDTIyMTIxODEzMjIwOFoXDTI0MDEw
MTEzMjIwOFowga4xCzAJBgNVBAYTAkRFMRYwFAYDVQQIDA1OaWVkZXJzYWNoc2Vu
MRIwEAYDVQQHDAlCYWQgSWJ1cmcxIDAeBgNVBAoMF0xXc3lzdGVtcyBHbWJIICYg
Q28uIEtHMSUwIwYDVQQDDBxCZW5ubyBNYWlsQXJjaGl2IFN1cHBvcnRpbmZvMSow
KAYJKoZIhvcNAQkBFhtzdXBwb3J0QGJlbm5vLW1haWxhcmNoaXYuZGUwggEiMA0G
CSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDCIdNAnl6zgc9vFHjG+oY6QEnis72
/QyLpZqd46+yLb88X8HaEoPM2kZDTS7Y//RN3/dtC0A+JfK+YhnCta4OwRIfMQtj
kEX4KsrRgJQMRErooiqs9/T1HHXgm56QhyfzpsKtv9a8AEgzDY+d/eFgtg3YeVYC
IoTpgahaU2M5JZm579RZcP8LcVw476sFdE83ZKq2tIGf65gUazxDpZsrxN+Hpk7x
JHA7fHpsc+DX0TCv+6jRTOJZF8w2RZ7y/nX6bLvA+JobBA+aLSB2wVkHOB1QkrLW
+dVCw4eFYPuHbPYjh16bXGypvyf75uG5Zkxg+oI+C8T1bmdvt/GCJHCNAgMBAAGj
UzBRMB0GA1UdDgQWBBT+bcyDb08R+Q9qbCQ/dvZw6PZmFzAfBgNVHSMEGDAWgBT+
bcyDb08R+Q9qbCQ/dvZw6PZmFzAPBgNVHRMBAf8EBTADAQH/MA0GCSqGSIb3DQEB
CwUAA4IBAQBN/MwZlO5yUWq3OgVH1bw8WzNzhCTCLiqlyj4d5qXmVik6ixPKDDbR
7UiLkT6ImcFSPO3KbvZJJyZBQK1i3ejIesINNZRgU4ToLuzXim6GdjWrQB9Bn37p
eWIEgNwUxvoYkHnefyO8afruoujesSLa7rI3aZNMZTtjsuS7KkuKuUvBQEmQQoeL
ZKZ1O0bYOm+M4Sbqxt675jcm1lIZOj/BDW1XYFcdMx/cmQL8iUD7bjCdBTFyTE/p
z49ieM9Qf7sEPLmjxpX8LQ5yTjOw11LxX5OcwovdNWfNjUM5Xw8sbAumjahgZQlM
rTRyqGMTIEQcEwjkMLuQeFC7957sSVR2
-----END CERTIFICATE-----
" > ${TMPDATA}/cert.pem
 
cd - > /dev/null
 
openssl smime -encrypt -aes256 -in ${TARGZ} -binary -outform DER -out ${ENCFILE} ${CERTFILE}
echo "Die Daten wurden zusammengestellt und verschluesselt."
echo ""

/bin/mv -i ${TARGZ}   ${TAROUT}
/bin/mv -i ${ENCFILE} ${ENCOUT}

echo "Das temporaere Verzeichnis \"${TMPDATA}\" kann geloescht werden:"
echo "  rm -r  \"${TMPDATA}\""
echo ""
echo "Unverschluesselte Daten: ${TAROUT}"
echo "Verschluesselte Daten:   ${ENCOUT}"
echo ""

